@@ -54,9 +54,9 @@ class OARepoS3Client(object):
         return self.do_upload()
 
     def do_upload(self):
-        for i in range(1, self.num_parts+1):
-            if self.results[i-1] is None:
-                self.parts_unfin.append(i)
+        for partNum in range(1, self.num_parts+1):
+            if self.results[partNum-1] is None:
+                self.parts_unfin.append(partNum)
         logger.debug(f"{funcname()} parts_unfin:\n{self.parts_unfin}")
         try:
             # parts_unfin = range(1, self.num_parts + 1)
@@ -70,16 +70,11 @@ class OARepoS3Client(object):
             if st == STATUS_OK:
                 logger.debug(f"{funcname()} parts:\n{self.parts}")
                 location = self.complete_upload()
-                return location
+                return location, STATUS_OK
             else:
                 raise Exception(f"Upload failed with status {st}.", st)
         except Exception as e:
             logger.debug(f"{funcname()} caught and raising Exception \"{e}\" {procname()}")
-            if click.confirm(f"\ncall abort_upload? (resume will not be possible)"):
-                self.abort_upload()
-            else:
-                secho(f'abort_upload skipped.\n resume info:')
-                secho(f'   -f "{self.file}" -k "{self.key}" -u "{self.uploadId}"')
             raise e
 
     def check_token_status(self, token):
@@ -98,6 +93,10 @@ class OARepoS3Client(object):
         self.urlUpload = f"{self.urlFiles}{self.key}/{self.uploadId}"
 
 
+    def get_uploadId(self):
+        return self.uploadId
+
+
     def set_file(self, file=None):
         if file is None or not path.exists(file) or not path.isfile(file):
             raise Exception(f"File not found ({file})", STATUS_WRONG_FILE)
